@@ -1,8 +1,8 @@
 #
 #	$RCSfile: syntax.pl,v $
-#	$Revision: 0.54 $
+#	$Revision: 0.55 $
 #	$Author: ripe-dbm $
-#	$Date: 1995/01/20 09:43:50 $
+#	$Date: 1995/02/10 13:53:46 $
 #
 #       ARGUMENTS:      *ASSOC object
 #       RETURNS:        INTEGER object_status
@@ -643,7 +643,7 @@ sub dosyntax {
 #
     if ($key eq "ch") {
 	local($i);
-	(@tmp) = split(/\s+/, $value);
+        (@tmp) = split(/\s+/, $value);
 	$email = "$tmp[0]";
 	foreach $i (1..$#tmp-1) { # This is for emails with spaces ;-(
 	    $email .= " $tmp[$i]";
@@ -660,10 +660,12 @@ sub dosyntax {
 	local($curdate) = "$y$mo$md";
 
 	if ($date eq "") {
-	    $object{$key} .= " $curdate";
-	    return $O_WARNING, 
-	    "todays date ($curdate) added to \"$ATTL{$key}\" attribute";
-	}
+	    # $object{$key} .= " $curdate";
+	    # return $O_WARNING, 
+	    # "todays date ($curdate) added to \"$ATTL{$key}\" attribute";
+	    return $O_ERROR, 
+	    "No date specified in \"$ATTL{$key}\" attribute";
+        }
 	if ($date !~ /^(\d\d)(\d\d)(\d\d)$/) {
 	    return $O_ERROR, "date part of \"$ATTL{$key}\"".
 		"not in YYMMDD format";
